0.6.0 (2016-06-07)
==================

* Исправлена авторизация в личном кабинете Мегафон. Была ошибка "CSRF token not found".

Спасибо [Андрею Дружинину](https://github.com/andrewdruzhinin).

0.5.0 (2016-04-25)
==================

* Добавлена поддержка провайдера ТрансТелеком.
* Исправлена работа с Tele2. Теперь mobile-balance тянет допольнительные зависимости, позволяющие корректно работать с серверами использующими SNI.

За оба улучшения, спасибо [Денису Рыкову](https://github.com/drnextgis)!

0.4.2 (2015-04-09)
==================

Исправлена работа с МТС, так как страница <https://login.mts.ru/amserver/UI/Login>
теперь отдает `401` код вместо `200`.

0.4.1 (2015-04-02)
==================

Исправлено получение баланса из личного кабинета МТС.
Там изменилась ручка, отдающая данные.

0.4.0 (2014-04-25)
==================

Теперь функции `get_balance` обязательно возвращают `float` значение
либо кидают исключение. Исключение может быть любое, но чаще это
`mobile_balance.exceptions.BadResponse`, сигнализирующее о том, что
либо получен ответ с неправильным кодом, либо в данных ответа не
содержится искомой информации.

В случае, если функция `get_balance` выбросила `BadResponse`, утилита
`mobile-balance` выводит сообщение об ошибке в `stderr`, а в `stdout` не выводит
ничего.

Так же, появилась новая опция командной строки: `--bad-responses-dir`.
Она позволяет указать директорию, в которую следует сохранить контент
страницы, вызвавшей исключение `BadResponse`.

0.3.3 (2014-04-24)
==================

* Исправлено получение баланса мегафона в случае, когда на счету более 1000 рублей.

0.3.2 (2014-04-18)
==================

* Исправлена работа с Мегафоном, в случае, когда баланс отрицателен.

0.3.1 (2014-04-07)
==================

* Теперь все функции get_balance должны возвращать либо float,
  либо None, если по каким-то причинам баланс получить не удалось.
* Больше нет зависимости от anyjson.

0.3.0 (2014-04-07)
==================

* Добавлена поддержка TELE2.

0.2.0 (2014-04-06)
==================

* Добавлена поддержка Мегафона.
* ChangeLog и README теперь на русском.

0.1.1 (2014-04-05)
==================

* Аргумент --number переименован в --phone

0.1.0 (2014-04-05)
=================

* Изначальная версия, работающая только с МТС.
